v1.11 - Nautobot ChatOps Documentation

Skip to content

# v1.11 Release Notes

## v1.11.0 (2023-03-11)

### Added

- #166 - Add documentation for contributing WebSocket Platform support.
- #171 - Enable Upstream Testing with Nautobot.
- #182 - Add option to limit Help prompt based on user Access Grants.

### Changed

- #94 - Clarified the description of Access Grants for Webex Teams.
- #147 - Left Align Column headers for tables to match the rows.
- #173 - Update App description.
- #174 - Change list views to use generic/object_list.html template.

### Removed

- #138 - Remove WEBEX_TOKEN warning when Webex is disabled.